@@ -62,7 +62,6 @@
 #endif
 
 #include    "message.h"
-#include    "d_memdebug.h"
 
 #ifdef MEMDEBUG
 #   define MEMMESSAGE(sss)      INFMESSAGE(sss)
@@ -116,25 +115,9 @@ typedef struct _LayoutConverterStruct {
    exit(0);						        \
 }
 
-extern int			layout_parse (
-#if NeedFunctionPrototypes
-    void *
-#endif
-);
-
-extern void			layout_scan_error (
-#if NeedFunctionPrototypes
-    char *,
-    void *
-#endif
-);
-
-extern int			layout_lex (
-#if NeedFunctionPrototypes
-    YYSTYPE *,
-    void *
-#endif
-); 
+extern int layout_parse (void *);
+extern void layout_scan_error (char *, void *);
+extern int layout_lex (YYSTYPE *, void *);
 
 #define layout_error(sss)       layout_scan_error(sss,YYLEX_PARAM)
 
@@ -142,13 +125,13 @@ extern int			layout_lex (
 /* Macros */
 /*---------------------------------------------------------*/
 
-#define New(ttt)      (ttt *) AAA_XtMalloc(sizeof(ttt))
-#define Dispose(xxx)  AAA_XtFree(xxx)
-#define Some(ttt,nnn) (ttt *) AAA_XtMalloc(sizeof(ttt)*nnn)
+#define New(ttt)      (ttt *) XtMalloc(sizeof(ttt))
+#define Dispose(xxx)  XtFree((XtPointer)xxx)
+#define Some(ttt,nnn) (ttt *) XtMalloc(sizeof(ttt)*nnn)
 #define More(xxx,ttt,nnn)   (			\
  (xxx) ?					\
- (ttt *) AAA_XtRealloc(xxx,sizeof(ttt)*nnn) :	\
- (ttt *) AAA_XtMalloc(sizeof(ttt)*nnn)		\
+ (ttt *) XtRealloc(xxx,sizeof(ttt)*nnn) :	\
+ (ttt *) XtMalloc(sizeof(ttt)*nnn)		\
 )
 
 #define GlueEqual(a,b)			\
