@@ -59,7 +59,6 @@
 #include <signal.h>
 
 #include "types.h"
-#include "d_memdebug.h"
 #include "main_resources.h"
 #include "main_globals.h"
 #include "misc.h"
@@ -518,7 +517,7 @@ Input(client_data, source, id)
 		struct record_list *ps_old = gvw->ghostview.ps_input;
 		gvw->ghostview.ps_input = ps_old->next;
 		if (ps_old->close) fclose(ps_old->fp);
-		GV_XtFree((char *)ps_old);
+		XtFree((char *)ps_old);
 	    }
 
 	    /* Have to seek at the beginning of each section */
@@ -838,7 +837,7 @@ Destroy(w)
     StopInterpreter(w);
     XtReleaseGC(w, gvw->ghostview.gc);
     XtReleaseGC(w, gvw->ghostview.highlight_gc);
-    if (gvw->ghostview.input_buffer) GV_XtFree(gvw->ghostview.input_buffer);
+    XtFree(gvw->ghostview.input_buffer);
     if (gvw->core.background_pixmap != XtUnspecifiedPixmap)
 	XFreePixmap(XtDisplay(w), gvw->core.background_pixmap);
     ENDMESSAGE(Destroy)
@@ -1416,8 +1415,8 @@ StartInterpreter(w)
     if (gvw->ghostview.disable_start) return;
 
     argv[argc++] = gvw->ghostview.interpreter;
-    if (app_res.antialias) dptr = device = GV_XtNewString(gv_gs_x11_alpha_device);
-    else                   dptr = device = GV_XtNewString(gv_gs_x11_device);
+    if (app_res.antialias) dptr = device = XtNewString(gv_gs_x11_alpha_device);
+    else                   dptr = device = XtNewString(gv_gs_x11_device);
     while (isspace(*dptr)) dptr++;
     while (*dptr) {
 	 argv[argc++] = dptr;
@@ -1441,7 +1440,7 @@ StartInterpreter(w)
        strcpy(parameter, "-sPDFPassword=");
        password = quote_filename(gv_pdf_password);
        strcat(parameter, password);
-       GV_XtFree(password);
+       XtFree(password);
        argv[argc++] = parameter;
     }
     
@@ -1460,7 +1459,7 @@ StartInterpreter(w)
       }
 
     if (gvw->ghostview.arguments) {
-	cptr = arguments = GV_XtNewString(gvw->ghostview.arguments);
+	cptr = arguments = XtNewString(gvw->ghostview.arguments);
 	while (isspace(*cptr)) cptr++;
 	while (*cptr) {
 	    argv[argc++] = cptr;
@@ -1616,6 +1615,8 @@ StartInterpreter(w)
 	    gvw->ghostview.interpreter_input = std_in[1];
 	    gvw->ghostview.interpreter_input_id = None;
 	} else if (strcmp(gvw->ghostview.filename, "-")) {
+	    gvw->ghostview.interpreter_input = std_in[1];
+	    gvw->ghostview.interpreter_input_id = None;
 	    close(std_in[0]);
 	}
 	close(std_out[1]);
@@ -1629,8 +1630,8 @@ StartInterpreter(w)
 	    XtAppAddInput(XtWidgetToApplicationContext(w), std_err[0],
 			  (XtPointer)XtInputReadMask, Output, (XtPointer)w);
     }
-    if (arguments) GV_XtFree(arguments);
-    if (device)    GV_XtFree(device);
+    XtFree(arguments);
+    XtFree(device);
     gvw->ghostview.background_cleared=0;
 
     ENDMESSAGE(StartInterpreter)
@@ -1669,7 +1670,7 @@ StopInterpreter(w)
 
 	    if (ps_old->close) fclose(ps_old->fp);
 
-	    GV_XtFree((char *)ps_old);
+	    XtFree((char *)ps_old);
 
 	  }
       }
@@ -1806,7 +1807,6 @@ static void GhostviewCornersPS(gvw,o,pslxP,psrxP,pslyP,psuyP)
 /*############################################################*/
 
 void
-#if NeedFunctionPrototypes
 GhostviewCoordsXtoPS(
   Widget w,
   int wx,
@@ -1814,14 +1814,6 @@ GhostviewCoordsXtoPS(
   int *psxP,
   int *psyP
 )
-#else
-GhostviewCoordsXtoPS(w,wx,wy,psxP,psyP)
-  Widget w;
-  int wx;
-  int wy;
-  int *psxP;
-  int *psyP;
-#endif
 {
   GhostviewWidget gvw = (GhostviewWidget) w;
   int o,x,y,pslx,psrx,psly,psuy,wrx,wly;
@@ -1833,11 +1825,11 @@ GhostviewCoordsXtoPS(w,wx,wy,psxP,psyP)
   *psyP = (psly + ((float)y*(float)(psuy-psly))/(float)wly + 0.5);
 #if 1
   {
-    int x,y;
+    int xx,yy;
     IIMESSAGE(wx,wy)
     IIMESSAGE(*psxP,*psyP)
-    GhostviewCoordsPStoX(w,*psxP,*psyP,&x,&y);
-    IIMESSAGE(x,y)
+    GhostviewCoordsPStoX(w,*psxP,*psyP,&xx,&yy);
+    IIMESSAGE(xx,yy)
   }
 #endif
   ENDMESSAGE(GhostviewCoordsXtoPS)
@@ -1848,7 +1840,6 @@ GhostviewCoordsXtoPS(w,wx,wy,psxP,psyP)
 /*############################################################*/
 
 void
-#if NeedFunctionPrototypes
 GhostviewCoordsPStoX(
   Widget w,
   int psx,
@@ -1856,14 +1847,6 @@ GhostviewCoordsPStoX(
   int *wxP,
   int *wyP
 )
-#else
-GhostviewCoordsPStoX(w,psx,psy,wxP,wyP)
-  Widget w;
-  int psx;
-  int psy;
-  int *wxP;
-  int *wyP;
-#endif
 {
   GhostviewWidget gvw = (GhostviewWidget) w;
   int o,pslx,psrx,psly,psuy,wrx,wly,*xP,*yP;
@@ -1884,7 +1867,6 @@ GhostviewCoordsPStoX(w,psx,psy,wxP,wyP)
 /*############################################################*/
 
 void
-#if NeedFunctionPrototypes
 GhostviewGetBBofArea (
   Widget   w,
   int x1,
@@ -1893,15 +1875,6 @@ GhostviewGetBBofArea (
   int y2,
   GhostviewReturnStruct* p
 )
-#else
-GhostviewGetBBofArea (w,x1,y1,x2,y2,p)
-  Widget w;
-  int x1;
-  int y1;
-  int x2;
-  int y2;
-  GhostviewReturnStruct* p;
-#endif
 {
   GhostviewWidget gvw = (GhostviewWidget) w;
   int psx1,psy1,psx2,psy2;
@@ -1925,7 +1898,6 @@ GhostviewGetBBofArea (w,x1,y1,x2,y2,p)
 /*############################################################*/
 
 void
-#if NeedFunctionPrototypes
 GhostviewGetAreaOfBB (
   Widget   w,
   int psx1,
@@ -1933,16 +1905,7 @@ GhostviewGetAreaOfBB (
   int psx2,
   int psy2,
   GhostviewReturnStruct* p
-) 
-#else
-GhostviewGetAreaOfBB (w,psx1,psy1,psx2,psy2,p)
-  Widget w;
-  int psx1;
-  int psy1;
-  int psx2;
-  int psy2;
-  GhostviewReturnStruct* p;
-#endif
+)
 {
   int x1,y1,x2,y2;
 
@@ -2027,20 +1990,12 @@ GhostviewEnableInterpreter(w)
 /*###################################################################################*/
 
 void
-#if NeedFunctionPrototypes
 GhostviewState(
     Widget w,
     Boolean *processflag_p,
     Boolean *busyflag_p,
     Boolean *inputflag_p
 )
-#else
-GhostviewState(w,processflag_p,busyflag_p,inputflag_p)
-    Widget w;
-    Boolean *processflag_p;
-    Boolean *busyflag_p;
-    Boolean *inputflag_p;
-#endif
 {
     GhostviewWidget gvw = (GhostviewWidget) w;
     BEGINMESSAGE(GhostviewState)
@@ -2131,27 +2086,22 @@ GhostviewIsInterpreterRunning(w)
 /*###################################################################################*/
 
 Boolean
-GhostviewSendPS(w, fp, begin, len, close)
-    Widget w;
-    FILE *fp;
-    gv_off_t begin;
-    gv_off_t len;
-    Bool close;
+GhostviewSendPS(Widget w, FILE *fp, gv_off_t begin, gv_off_t len, Bool doclose)
 {
     GhostviewWidget gvw = (GhostviewWidget) w;
     struct record_list *ps_new;
 
     if (gvw->ghostview.interpreter_input < 0) return False;
-    ps_new = (struct record_list *) GV_XtMalloc(sizeof (struct record_list));
+    ps_new = (struct record_list *) XtMalloc(sizeof (struct record_list));
     ps_new->fp = fp;
     ps_new->begin = begin;
     ps_new->len = len;
     ps_new->seek_needed = True;
-    ps_new->close = close;
+    ps_new->close = doclose;
     ps_new->next = NULL;
 
     if (gvw->ghostview.input_buffer == NULL) {
-	gvw->ghostview.input_buffer = GV_XtMalloc(GV_BUFSIZ);
+	gvw->ghostview.input_buffer = XtMalloc(GV_BUFSIZ);
     }
 
     if (gvw->ghostview.ps_input == NULL) {
