@@ -82,7 +82,6 @@
 #include "actions.h"
 #include "callbacks.h"
 #include "confirm.h"
-#include "d_memdebug.h"
 #include "dialog.h"
 #include "error.h"
 #include "file.h"
@@ -456,11 +455,11 @@ int main(argc, argv)
      */
      const char *xufsp="XUSERFILESEARCHPATH";
      char *xuf;
-     xuf = getenv(xufsp); if (xuf) xuf = GV_XtNewString(xuf);
+     xuf = getenv(xufsp); if (xuf) xuf = XtNewString(xuf);
      gnu_gv_setenv(xufsp,"___",1);
      gv_display = XtOpenDisplay(app_con,NULL,NULL,gv_class,NULL,0,&argc,argv);
 
-     if (xuf) { gnu_gv_setenv(xufsp,xuf,1); GV_XtFree(xuf); } else gnu_gv_unsetenv(xufsp);
+     if (xuf) { gnu_gv_setenv(xufsp,xuf,1); XtFree(xuf); } else gnu_gv_unsetenv(xufsp);
      if (gv_display)
         XtGetApplicationNameAndClass(gv_display,&gv_name,&gv_class);
      SMESSAGE(gv_name) SMESSAGE(gv_class)
@@ -634,7 +633,7 @@ int main(argc, argv)
 	   exit(0);
 
 	 case PASSWORD_ARG:
-	   gv_pdf_password = GV_XtNewString(optarg);
+	   gv_pdf_password = XtNewString(optarg);
 	   break;
 
 	 case SPARTAN_ARG:
@@ -664,20 +663,6 @@ int main(argc, argv)
        exit(EXIT_STATUS_ERROR);
      }
 
-     if (access(gv_safe_gs_workdir, R_OK | X_OK))
-     {
-        char buffer[512];
-	strcpy(buffer, "/tmp/gv-safe-workdir-XXXXXX");
-        gv_safe_gs_workdir = mkdtemp(buffer);
-	gv_safe_gs_tempdir = 1;
-
-	if (!gv_safe_gs_workdir)
-	{
-	   perror("Cannot create safe workdir");
-	   exit(1);
-	}
-     }  
-
    /*### getting resources ############################################*/
    gv_database = resource_buildDatabase (gv_display,
                                          gv_class,
@@ -708,11 +693,26 @@ int main(argc, argv)
     XtGetApplicationResources(toplevel,(XtPointer) &app_res,resources,XtNumber(resources),NULL,ZERO);
     if (!resource_checkResources(gv_name,app_res.version,versionCompatibility)) {
       XtDestroyApplicationContext(app_con);
-      clean_safe_tempdir();
       exit(EXIT_STATUS_ERROR);
     }
 
 /*### initialization of global variables based on resource ##################*/
+     if (access(gv_safe_gs_workdir, R_OK | X_OK))
+     {
+        char buffer[512];
+	strcpy(buffer, app_res.scratch_dir);
+	strcat(buffer,"gv-safe-workdir-XXXXXX");
+	file_translateTildeInPath(buffer);
+        gv_safe_gs_workdir = strdup(mkdtemp(buffer));
+	gv_safe_gs_tempdir = 1;
+
+	if (!gv_safe_gs_workdir)
+	{
+	   perror("Cannot create safe workdir");
+	   exit(1);
+	}
+     }  
+
 
     main_setGhostscriptResources(gv_database);
     main_setInternResource(gv_database,&gv_print_command,"printCommand");
@@ -738,20 +738,20 @@ int main(argc, argv)
     app_res.minimum_height = app_res.minimum_height < 300 ? 300 : app_res.minimum_height; 
 
     gv_medias_res = resource_getResource(gv_database,gv_class,gv_name,"medias","Medias");
-    gv_medias_res = GV_XtNewString(gv_medias_res);
+    gv_medias_res = XtNewString(gv_medias_res);
     gv_medias = media_parseMedias(gv_medias_res);
     gv_num_std_pagemedia = media_numMedias(gv_medias);
 
     gv_magmenu_entries_res = resource_getResource(gv_database,gv_class,gv_name,"magMenu","MagMenu");
-    gv_magmenu_entries_res = GV_XtNewString(gv_magmenu_entries_res);
+    gv_magmenu_entries_res = XtNewString(gv_magmenu_entries_res);
     gv_magmenu_entries = magmenu_parseMagMenuEntries(gv_magmenu_entries_res);
 
     gv_miscmenu_entries_res = resource_getResource(gv_database,gv_class,gv_name,"miscMenuEntries","MiscMenuEntries");
-    gv_miscmenu_entries_res = GV_XtNewString(gv_miscmenu_entries_res);
+    gv_miscmenu_entries_res = XtNewString(gv_miscmenu_entries_res);
     gv_miscmenu_entries = miscmenu_parseMiscMenuEntries(gv_miscmenu_entries_res);
     
     gv_scales_res = resource_getResource(gv_database,gv_class,gv_name,"scales","Scales");
-    gv_scales_res = GV_XtNewString(gv_scales_res);
+    gv_scales_res = XtNewString(gv_scales_res);
     gv_scales = scale_parseScales(gv_scales_res);
     gv_scale_current = gv_scale_base_current = -1;
 
@@ -922,7 +922,7 @@ int main(argc, argv)
        XtSetArg(args[n], XtNmaximumHeight,maximum_height);n++; 
        XtSetArg(args[n], XtNminimumWidth, (Dimension)app_res.minimum_width); n++;
        XtSetArg(args[n], XtNminimumHeight,(Dimension)app_res.minimum_height);n++; 
-       control = XtCreateWidget("control",aaaWidgetClass,toplevel,args,n);
+       main_control = XtCreateWidget("control",aaaWidgetClass,toplevel,args,n);
     }
 
 /*### Creating the Menus ###############################################################*/
@@ -1019,20 +1019,20 @@ int main(argc, argv)
    {
 							n=0;
      XtSetArg(args[n], XtNresize, True);		n++;
-     pagemediaButton = XtCreateWidget("pagemediaButton",mbuttonWidgetClass,control,args,n);
+     pagemediaButton = XtCreateWidget("pagemediaButton",mbuttonWidgetClass,main_control,args,n);
      cont_child[cont_child_num] = pagemediaButton; cont_child_num++;
    }
 
    {
            					n=0;
      XtSetArg(args[n], XtNresize, False);	n++;
-     processButton = XtCreateWidget("processButton", mbuttonWidgetClass,control,args,n);
+     processButton = XtCreateWidget("processButton", mbuttonWidgetClass,main_control,args,n);
      cont_child[cont_child_num] = processButton; cont_child_num++;
      processMenu=NULL;
    }
 
 							n=0;
-     scaleButton = XtCreateWidget("scaleButton",mbuttonWidgetClass,control,args,n);
+     scaleButton = XtCreateWidget("scaleButton",mbuttonWidgetClass,main_control,args,n);
      cont_child[cont_child_num] =scaleButton; cont_child_num++;
      main_createScaleMenu();
 
@@ -1083,7 +1083,7 @@ int main(argc, argv)
              INFSMESSAGE(creating widget,b[i].name)
              *(b[i].show) = strstr(layout,b[i].name) ? True : False;
              if (*(b[i].show)) {
-                *(b[i].widget) = XtCreateWidget(b[i].name,buttonWidgetClass,control,args,n);
+                *(b[i].widget) = XtCreateWidget(b[i].name,buttonWidgetClass,main_control,args,n);
                 if (b[i].callback) XtAddCallback(*(b[i].widget),XtNcallback,b[i].callback,b[i].client_data);
                 cont_child[cont_child_num] = *(b[i].widget); cont_child_num++;
              }
@@ -1109,7 +1109,7 @@ int main(argc, argv)
          widgetname=name;							\
          show = strstr(layout,widgetname) ? True : False;			\
          if (show) {								\
-            widget = XtCreateWidget(widgetname,mbuttonWidgetClass,control,args,n);\
+            widget = XtCreateWidget(widgetname,mbuttonWidgetClass,main_control,args,n);\
             cont_child[cont_child_num] = widget; cont_child_num++;		\
          }
 
@@ -1124,7 +1124,7 @@ int main(argc, argv)
           char buf[MAX_LOCATOR_LENGTH];
           sprintf(buf,app_res.locator_format,9999,9999);
           XtSetArg(args[n], XtNlabel,buf);		n++;
-          locator = XtCreateWidget(widgetname,labelWidgetClass,control,args,n);
+          locator = XtCreateWidget(widgetname,labelWidgetClass,main_control,args,n);
           cont_child[cont_child_num] =locator; cont_child_num++;
        }
 #      undef _mw_
@@ -1136,7 +1136,7 @@ int main(argc, argv)
        if (show_panner) {
 
   									n=0;
-          pannerFrame = XtCreateWidget("pannerFrame",frameWidgetClass,control,args,n);
+          pannerFrame = XtCreateWidget("pannerFrame",frameWidgetClass,main_control,args,n);
           cont_child[cont_child_num] = pannerFrame; cont_child_num++;
   									n=0;
           panner = XtCreateManagedWidget("panner", compositeWidgetClass,pannerFrame, args, n);
@@ -1154,7 +1154,7 @@ int main(argc, argv)
 
 
   									n=0;
-          newtocFrame = XtCreateWidget("newtocFrame",frameWidgetClass,control,args,n);
+          newtocFrame = XtCreateWidget("newtocFrame",frameWidgetClass,main_control,args,n);
           cont_child[cont_child_num] = newtocFrame; cont_child_num++;
   									n=0;
           newtocClip = XtCreateManagedWidget("newtocClip", clipWidgetClass,newtocFrame, args, n);
@@ -1164,7 +1164,7 @@ int main(argc, argv)
           newtoc = XtCreateManagedWidget("newtoc", vlistWidgetClass,newtocControl, args, n);
 	  XtAddCallback(newtoc, XtNreportCallback,cb_newtocVisibleAdjust, (XtPointer)NULL);
 									n=0;
-          newtocScroll = XtCreateWidget("newtocScroll", scrollbarWidgetClass,control, args, n);
+          newtocScroll = XtCreateWidget("newtocScroll", scrollbarWidgetClass,main_control, args, n);
 	     XtAddCallback(newtocScroll, XtNscrollProc,cb_newtocScrollbar, (XtPointer)1);
              XtAddCallback(newtocScroll, XtNjumpProc,cb_newtocScrollbar, (XtPointer)2);
 
@@ -1175,7 +1175,7 @@ int main(argc, argv)
    INFMESSAGE(viewport)
 
 									n=0;
-   viewFrame = XtCreateWidget("viewFrame", frameWidgetClass,control,args,n);
+   viewFrame = XtCreateWidget("viewFrame", frameWidgetClass,main_control,args,n);
    cont_child[cont_child_num] = viewFrame; cont_child_num++;
 
 									n=0;
@@ -1216,7 +1216,7 @@ int main(argc, argv)
 
    if (argc == optind + 1) 
      {
-       gv_filename=GV_XtNewString(argv[optind]);
+       gv_filename=XtNewString(argv[optind]);
      }
 
    if (gv_filename && strcmp(gv_filename, "-")) {
@@ -1225,7 +1225,7 @@ int main(argc, argv)
 	clean_safe_tempdir();
 	exit(EXIT_STATUS_ERROR);
       } else {
-        GV_XtFree(gv_filename_old);
+        XtFree(gv_filename_old);
         gv_filename_old = NULL;
       }
    }
@@ -1285,7 +1285,7 @@ int main(argc, argv)
     INFMESSAGE(managing children of control)
     XtManageChildren((WidgetList)cont_child,cont_child_num);
     INFMESSAGE(managing control)
-    XtManageChild(control);
+    XtManageChild(main_control);
     XtSetMappedWhenManaged(toplevel, False);
     INFMESSAGE(realizing toplevel)
     XtRealizeWidget(toplevel);
@@ -1316,9 +1316,9 @@ int main(argc, argv)
     XtSetArg(args[n], XtNdirs,    &gv_dirs);	n++;
     XtSetArg(args[n], XtNfilter,  &gv_filter);	n++;
     XtGetValues(FileSel,args,n);
-    gv_filters = GV_XtNewString(gv_filters);
-    gv_dirs    = GV_XtNewString(gv_dirs);
-    gv_filter  = GV_XtNewString(gv_filter);
+    gv_filters = XtNewString(gv_filters);
+    gv_dirs    = XtNewString(gv_dirs);
+    gv_filter  = XtNewString(gv_filter);
 
 /*### now we become visible ######################################################*/
 
@@ -1353,7 +1353,7 @@ int main(argc, argv)
     cb_watchFile(watchFileEntry,NULL,NULL);
 
     /* must allow control to resize */
-    AaaWidgetAllowResize((AaaWidget)control,True,True);
+    AaaWidgetAllowResize((AaaWidget)main_control,True,True);
 
     if (fullscreen_p) {
       Atom net_wm_state;
@@ -1399,7 +1399,7 @@ static void main_createMenu(m,list,numP)
   SMESSAGE(m[0].name)
 
 							n=0;
-  *(m[0].widgetP) = XtCreateManagedWidget(m[0].name,mbuttonWidgetClass,control,args,n);
+  *(m[0].widgetP) = XtCreateManagedWidget(m[0].name,mbuttonWidgetClass,main_control,args,n);
     list[*numP] = *(m[0].widgetP); (*numP)++;
 
 							n=0;
@@ -1430,7 +1430,7 @@ void main_setInternResource(db,sP,name)
   BEGINMESSAGE(main_setInternResource)
   *sP = resource_getResource(db,gv_class,gv_class,name,NULL);
   if (!*sP) *sP="";
-  *sP = GV_XtNewString(*sP);
+  *sP = XtNewString(*sP);
   ENDMESSAGE(main_setInternResource)
 }
 
@@ -1569,7 +1569,7 @@ void main_createScaleMenu(void)
 							n=0;
   scaleMenu = XtCreatePopupShell("menu", simpleMenuWidgetClass,scaleButton,args,n);
   for (i=0; gv_scales[i]; i++);
-  scaleEntry = (Widget*) GV_XtMalloc(i*sizeof(Widget));
+  scaleEntry = (Widget*) XtMalloc(i*sizeof(Widget));
   for (i=0; gv_scales[i]; i++) {
     if (!have_line && !gv_scales[i]->is_base) {
       XtCreateManagedWidget("line", smeLineObjectClass,scaleMenu,NULL,(Cardinal)0);
