@@ -59,7 +59,6 @@
 
 #include "types.h"
 #include "callbacks.h"
-#include "d_memdebug.h"
 #include "file.h"
 #include "widgets_misc.h"
 #include "main_resources.h"
@@ -74,7 +73,7 @@
 #include "version.h"
 
 static Widget   popup=NULL,optionControl;
-static Widget   quietToggle,saferToggle;
+static Widget   quietToggle,saferToggle,safeDirToggle;
 static Widget   scan,conv,gs,x11dev,x11alphadev,arguments;
 
 static void options_gs_setOptionsAtEntry(void);
@@ -103,6 +102,7 @@ static void options_gs_setOptionsAtEntry(void)
 {
   BEGINMESSAGE(options_gs_setOptionsAtEntry)
 
+  widgets_setToggle(safeDirToggle, gv_gs_safeDir);
   widgets_setToggle(saferToggle, gv_gs_safer);
   widgets_setToggle(quietToggle, gv_gs_quiet);
 
@@ -140,7 +140,7 @@ static Boolean options_gs_change (w,sP,fP)
       *fP = *sP;
       *sP = v;
       r = True;
-  } else GV_XtFree(v);
+  } else XtFree(v);
   ENDMESSAGE(options_gs_change)
   return(r);
 }
@@ -149,11 +149,11 @@ static void options_gs_cb_apply(w, client_data, call_data)
    Widget	w;
    XtPointer	client_data, call_data;
 {
-   Arg args[5];
+   Arg args[10];
    Cardinal n;
    int i;
    Boolean reopen=False;
-   String free[6] = {NULL,NULL,NULL,NULL,NULL,NULL};
+   String f[6] = {NULL,NULL,NULL,NULL,NULL,NULL};
 
    BEGINMESSAGE(options_gs_cb_apply)
 
@@ -165,17 +165,24 @@ static void options_gs_cb_apply(w, client_data, call_data)
    gv_gs_safer = SwitchIsSet(saferToggle) ? 1 : 0;
    if (i != gv_gs_safer) reopen=True;
 
-   reopen |= options_gs_change(gs,&gv_gs_interpreter,&(free[0]));
-   reopen |= options_gs_change(scan,&gv_gs_cmd_scan_pdf,&(free[1]));
-            options_gs_change(conv,&gv_gs_cmd_conv_pdf,&(free[2]));
-   reopen |= options_gs_change(x11dev,&gv_gs_x11_device,&(free[3]));
-   reopen |= options_gs_change(x11alphadev,&gv_gs_x11_alpha_device,&(free[4]));
-   reopen |= options_gs_change(arguments,&gv_gs_arguments,&(free[5]));
+   i = gv_gs_safeDir;
+   gv_gs_safeDir = SwitchIsSet(safeDirToggle) ? 1 : 0;
+   if (i != gv_gs_safeDir) reopen=True;
+
+   reopen |= options_gs_change(gs,&gv_gs_interpreter,&(f[0]));
+   reopen |= options_gs_change(scan,&gv_gs_cmd_scan_pdf,&(f[1]));
+            options_gs_change(conv,&gv_gs_cmd_conv_pdf,&(f[2]));
+   reopen |= options_gs_change(x11dev,&gv_gs_x11_device,&(f[3]));
+   reopen |= options_gs_change(x11alphadev,&gv_gs_x11_alpha_device,&(f[4]));
+   reopen |= options_gs_change(arguments,&gv_gs_arguments,&(f[5]));
 
    if (reopen) {
      cb_stopInterpreter(page,NULL,NULL);
 								n=0;
      XtSetArg(args[n], XtNinterpreter,gv_gs_interpreter);	n++;
+     if (gv_gs_safeDir)  XtSetArg(args[n], XtNsafeDir,True);
+     else              XtSetArg(args[n], XtNsafeDir,False);
+                                                                n++;
      if (gv_gs_safer)  XtSetArg(args[n], XtNsafer,True);
      else              XtSetArg(args[n], XtNsafer,False);
                                                                 n++;
@@ -186,7 +193,7 @@ static void options_gs_cb_apply(w, client_data, call_data)
      XtSetValues(page, args, n);
      if (gv_filename) show_page(REQUEST_REOPEN,NULL);
    }
-   for (i=0; i<6 ; i++) if (free[i]) GV_XtFree(free[i]);
+   for (i=0; i<6 ; i++) XtFree(f[i]);
 
    ENDMESSAGE(options_gs_cb_apply)
 }
@@ -208,7 +215,7 @@ static void options_gs_setArg(w,argiP,argvP,argnP,format,name)
   s = options_squeeze(s);
   options_setArg(argiP,argvP,format,name,s);
   ++(*argnP);
-  GV_XtFree(s);
+  XtFree(s);
 }
 
 static
@@ -217,8 +224,8 @@ void options_gs_cb_save(w, client_data, call_data)
   XtPointer	client_data, call_data;
 {
   int    argn = 0;
-  String argi[10];
-  String argv[10];
+  String argi[20];
+  String argv[20];
   String t = "True";
   String f = "False";
 
@@ -233,6 +240,8 @@ void options_gs_cb_save(w, client_data, call_data)
   options_gs_setArg(x11alphadev,&(argi[argn]),&(argv[argn]),&argn,s_gsX11AlphaDevice ,gv_class);
   options_gs_setArg(arguments  ,&(argi[argn]),&(argv[argn]),&argn,s_gsArguments      ,gv_class);
 
+  options_setArg(&(argi[argn]),&(argv[argn]),s_gsSafeDir        ,gv_class ,SwitchIsSet(safeDirToggle) ? t : f);
+  ++argn;
   options_setArg(&(argi[argn]),&(argv[argn]),s_gsSafer          ,gv_class ,SwitchIsSet(saferToggle) ? t : f);
   ++argn;
   options_setArg(&(argi[argn]),&(argv[argn]),s_gsQuiet          ,gv_class ,SwitchIsSet(quietToggle) ? t : f);
@@ -240,8 +249,8 @@ void options_gs_cb_save(w, client_data, call_data)
 
   options_save(argn,argi,argv);
   while (--argn >=0) {
-    GV_XtFree(argi[argn]); 
-    GV_XtFree(argv[argn]);
+    XtFree(argi[argn]);
+    XtFree(argv[argn]);
   }
 
   ENDMESSAGE(options_gv_cb_save)
@@ -291,6 +300,7 @@ void options_gs_create(void)
          						n=0;
    optionControl = XtCreateManagedWidget("optionControl",aaaWidgetClass,popup,args,n);
 
+   safeDirToggle      = XtCreateManagedWidget("safeDir",switchWidgetClass,optionControl,NULL,(Cardinal)0);
    saferToggle        = XtCreateManagedWidget("safer",switchWidgetClass,optionControl,NULL,(Cardinal)0);
    quietToggle        = XtCreateManagedWidget("quiet",switchWidgetClass,optionControl,NULL,(Cardinal)0);
  
