@@ -97,7 +97,7 @@
 #include "misc.h"
 #include "ps.h"
 #include "note.h"
-#include "d_memdebug.h"
+#include "actions.h"
 extern Media *gv_medias;
 extern String gv_pdf_password;
 extern String gv_safe_gs_workdir;
@@ -122,14 +122,14 @@ static int dsc_strncmp(s1, s2, n)
  if (strncasecmp(s1, s2, n) == 0)
 	 return 0;
  if (s2[n-1] == ':'){
-	 tmp = (char *) PS_malloc(n*sizeof(char));
+	 tmp = (char *) malloc(n*sizeof(char));
 	 strncpy(tmp, s2, (n-1));
 	 tmp[n-1]=' ';
 	 if (strncasecmp(s1, tmp, n) == 0){
-		 PS_free(tmp);
+		 free(tmp);
 		 return 0;
 	 }
-	 PS_free(tmp);
+	 free(tmp);
  }
  
  return 1;
@@ -169,13 +169,6 @@ struct documentmedia papersizes[] = {
 };
 #endif
 
-
-#if NeedFunctionPrototypes
-#   define PT(aaa) aaa
-#else 
-#   define PT(aaa) ()
-#endif
-
 /*--------------------------------------------------*/
 /* Declarations for ps_io_*() routines. */
 
@@ -195,18 +188,18 @@ typedef struct FileDataStruct_ {
    int   status;         /* 0 = okay, 1 = failed */
 } FileDataStruct;
 
-static FileData ps_io_init PT((FILE *));
-static void     ps_io_exit PT((FileData));
-static char    *ps_io_fgetchars PT((FileData, int));
+static FileData ps_io_init (FILE *);
+static void     ps_io_exit (FileData);
+static char    *ps_io_fgetchars (FileData, int);
 
-static int      ps_io_fseek PT((FileData, gv_off_t));
-static gv_off_t     ps_io_ftell PT((FileData));
-static char    *readline PT((FileData, char **, gv_off_t *, unsigned int *));
+static int      ps_io_fseek (FileData, gv_off_t);
+static gv_off_t ps_io_ftell (FileData);
+static char    *readline (FileData, char **, gv_off_t *, unsigned int *);
 
-static char    *gettextline PT((char *));
-static char    *ps_gettext PT((char *,char **));
-static int      blank PT((char *));
-static char    *pscopyuntil PT((FileData,FILE *,long,long,char *));
+static char    *gettextline (char *);
+static char    *ps_gettext (char *,char **);
+static int      blank (char *);
+static char    *pscopyuntil (FileData,FILE *,long,long,char *);
 
 static char    *skipped_line = "% ps_io_fgetchars: skipped line";
 static char    *empty_string = "";
@@ -408,7 +401,7 @@ psscan(fileP,filename,filename_raw,filename_dscP,cmd_scan_pdf,filename_uncP,cmd_
 #ifndef HAVE_ZIO
     if (cmd_uncompress) {
       struct document *retval = NULL;
-      FILE *tmpfile = (FILE*)NULL;
+      FILE *tempfile = (FILE*)NULL;
       char *filename_unc;
       char *quoted_filename, *quoted_filename_unc;
       char cmd[512];
@@ -429,8 +422,8 @@ psscan(fileP,filename,filename_raw,filename_dscP,cmd_scan_pdf,filename_uncP,cmd_
       } else {
         sprintf(cmd, "gzip -dc %s >%s", quoted_filename, quoted_filename_unc);
       }
-      GV_XtFree(quoted_filename);
-      GV_XtFree(quoted_filename_unc);
+      XtFree(quoted_filename);
+      XtFree(quoted_filename_unc);
 
 
       INFMESSAGE(is compressed)
@@ -443,18 +436,18 @@ unc_exec_failed:
 unc_failed:
 #endif
 	NotePopupShowMessage(s);
-	if (tmpfile) fclose(tmpfile);
+	if (tempfile) fclose(tempfile);
 	unlink(filename_unc);
 unc_ok:
-	GV_XtFree(filename_unc);
+	XtFree(filename_unc);
 	ENDMESSAGE(psscan)
         return(retval);
       }
       umask(old_umask);
-      tmpfile = fopen(filename_unc, "r");
-      if (!tmpfile) goto unc_exec_failed;
+      tempfile = fopen(filename_unc, "r");
+      if (!tempfile) goto unc_exec_failed;
       fclose(*fileP);
-      *fileP = tmpfile;
+      *fileP = tempfile;
       retval = psscan(fileP,filename_unc,filename_raw,filename_dscP,cmd_scan_pdf,NULL,NULL,scanstyle, gv_gs_safeDir);
 #if 0
       if (!retval) {
@@ -462,7 +455,7 @@ unc_ok:
 	goto unc_failed;
       }
 #endif
-      *filename_uncP = (char*)GV_XtNewString(filename_unc);
+      *filename_uncP = (char*)XtNewString(filename_unc);
       goto unc_ok;
     }
 #else
@@ -506,7 +499,7 @@ unc_ok:
     if (line_len>1 && (iscomment(line,"%!PS-Adobe-") || iscomment(line + 1,"%!PS-Adobe-"))) {
       INFMESSAGE(found "PS-Adobe-" comment)
 
-      doc = (struct document *) PS_malloc(sizeof(struct document));
+      doc = (struct document *) malloc(sizeof(struct document));
       CHECK_MALLOCED(doc);
       memset(doc, 0, sizeof(struct document));
       *text=0;
@@ -519,7 +512,7 @@ unc_ok:
     } else if (iscomment(line,"%PDF-") && cmd_scan_pdf) {
       
       struct document *retval = NULL;
-      FILE *tmpfile = (FILE*)NULL;
+      FILE *tempfile = (FILE*)NULL;
       char *filename_dsc;
       char *quoted_filename, *quoted_filename_dsc;
       char *pdfpos;
@@ -533,7 +526,7 @@ unc_ok:
       filename_dsc=file_getTmpFilename(NULL, filename_raw, NULL);
       if (!filename_dsc) {
 	NotePopupShowMessage("Cannot create temporary file!");
-	if (tmpfile) fclose(tmpfile);
+	if (tempfile) fclose(tempfile);
         ps_io_exit(fd);
 	ENDMESSAGE(psscan)
         return(retval);
@@ -565,14 +558,14 @@ unc_ok:
 	   strcpy(parameter, " -sPDFPassword=");
 	   password = quote_filename(gv_pdf_password);
 	   strcat(parameter, password);
-	   GV_XtFree(password);
+	   XtFree(password);
 	   sprintf(cmd,cmd_scan_pdf,quoted_filename,quoted_filename_dsc, parameter);
 	}
 	else   
 	   sprintf(cmd,cmd_scan_pdf,quoted_filename,quoted_filename_dsc, "");
       }
-      GV_XtFree(quoted_filename);
-      GV_XtFree(quoted_filename_dsc);
+      XtFree(quoted_filename);
+      XtFree(quoted_filename_dsc);
 
       old_umask = umask(0077);
       INFMESSAGE(is PDF)
@@ -596,7 +589,7 @@ unc_ok:
 
 
       if (system(cmd) || file_fileIsNotUseful(filename_dsc)) {
-        char line[1000];
+        char password_line[1000];
 	int found;
 	FILE* tmp_file;
 	
@@ -608,11 +601,11 @@ unc_ok:
 	close(tmpfd);
 
         tmp_file = fopen( tmp_filename, "r" );
-	while ( fgets( line, 999, tmp_file) )
+	while ( fgets( password_line, 999, tmp_file) )
 	{
-	   if (strstr(line,"This file requires a password for access."))
+	   if (strstr(password_line,"This file requires a password for access."))
 	      found = 1;
-	   if (strstr(line,"Password did not work."))
+	   if (strstr(password_line,"Password did not work."))
 	      found = 1;
         }
 	fclose(tmp_file);	
@@ -626,17 +619,17 @@ unc_ok:
 	   goto scan_password_required;
 	   /* TODO? but wait for password dialog */
 	}
-        GV_XtFree(tmp_filename);
+        XtFree(tmp_filename);
 	
 scan_exec_failed:
 	sprintf(s,"Execution of\n%s\nfailed.",cmd);
 scan_failed:
 	NotePopupShowMessage(s);
 scan_password_required:
-	if (tmpfile) fclose(tmpfile);
+	if (tempfile) fclose(tempfile);
 	unlink(filename_dsc);
 scan_ok:
-	GV_XtFree(filename_dsc);
+	XtFree(filename_dsc);
         ps_io_exit(fd);
 	ENDMESSAGE(psscan)
         return(retval);
@@ -648,19 +641,19 @@ scan_ok:
       close(tmp_fd);
       
       unlink((char*) tmp_filename);
-      GV_XtFree(tmp_filename);
+      XtFree(tmp_filename);
 
       umask (old_umask);
-      tmpfile = fopen(filename_dsc, "r");
-      if (!tmpfile) goto scan_exec_failed;
+      tempfile = fopen(filename_dsc, "r");
+      if (!tempfile) goto scan_exec_failed;
       fclose(*fileP);
-      *fileP = tmpfile;
+      *fileP = tempfile;
       retval = psscan(fileP,filename_dsc,filename_raw,filename_dscP,cmd_scan_pdf,NULL,NULL,scanstyle,gv_gs_safeDir);
       if (!retval) {
 	sprintf(s,"Scanning\n%s\nfailed.",filename_dsc);
 	goto scan_failed;
       }
-      *filename_dscP = (char*)GV_XtNewString(filename_dsc);
+      *filename_dscP = (char*)XtNewString(filename_dsc);
       goto scan_ok;
     } else {
       INFMESSAGE(unable to classify document)
@@ -763,7 +756,7 @@ scan_ok:
 			}
 		    case 1:
 			if (maxpages > 0) {
-			    doc->pages = (struct page *) PS_calloc(maxpages,
+			    doc->pages = (struct page *) calloc(maxpages,
 							   sizeof(struct page));
                             CHECK_MALLOCED(doc->pages);
 			}
@@ -773,7 +766,7 @@ scan_ok:
 		   iscomment(line+2, "DocumentMedia:")) {
 	    float w, h;
 	    doc->media = (Media)
-			 PS_malloc(sizeof (MediaStruct));
+			 malloc(sizeof (MediaStruct));
             CHECK_MALLOCED(doc->media);
 	    doc->media[0].name = ps_gettext(line+length("%%DocumentMedia:"),
 					    &next_char);
@@ -785,14 +778,14 @@ scan_ok:
 		if (doc->media[0].width != 0 && doc->media[0].height != 0)
 		    doc->nummedia = 1;
 		else
-		    PS_free(doc->media[0].name);
+		    free(doc->media[0].name);
 	    }
 	    preread=1;
 	    while (readline(fd, &line, &position, &line_len) &&
 		   DSCcomment(line) && iscomment(line+2, "+")) {
 		section_len += line_len;
 		doc->media = (Media)
-			     PS_realloc(doc->media,
+			     realloc(doc->media,
 				     (doc->nummedia+1)*
 				     sizeof (MediaStruct));
                 CHECK_MALLOCED(doc->media);
@@ -806,7 +799,7 @@ scan_ok:
 		    if (doc->media[doc->nummedia].width != 0 &&
 			doc->media[doc->nummedia].height != 0) doc->nummedia++;
 		    else
-			PS_free(doc->media[doc->nummedia].name);
+			free(doc->media[doc->nummedia].name);
 		}
 	    }
 	    section_len += line_len;
@@ -815,7 +808,7 @@ scan_ok:
 		   iscomment(line+2, "DocumentPaperSizes:")) {
 
 	    doc->media = (Media)
-			 PS_malloc(sizeof (MediaStruct));
+			 malloc(sizeof (MediaStruct));
             CHECK_MALLOCED(doc->media);
 	    doc->media[0].name = ps_gettext(line+length("%%DocumentPaperSizes:"),
 					    &next_char);
@@ -829,8 +822,8 @@ scan_ok:
 		     * PaperSize comments.
 		     */
 		    if (strcasecmp(doc->media[0].name, dmp->name) == 0) {
-			PS_free(doc->media[0].name);
-			doc->media[0].name = (char *)PS_malloc(strlen(dmp->name)+1);
+			free(doc->media[0].name);
+			doc->media[0].name = (char *)malloc(strlen(dmp->name)+1);
                         CHECK_MALLOCED(doc->media[0].name);
 			strcpy(doc->media[0].name, dmp->name);
 			doc->media[0].width = dmp->width;
@@ -841,11 +834,11 @@ scan_ok:
 		if (doc->media[0].width != 0 && doc->media[0].height != 0)
 		    doc->nummedia = 1;
 		else
-		    PS_free(doc->media[0].name);
+		    free(doc->media[0].name);
 	    }
 	    while ((cp = ps_gettext(next_char, &next_char))) {
 		doc->media = (Media)
-			     PS_realloc(doc->media,
+			     realloc(doc->media,
 				     (doc->nummedia+1)*
 				     sizeof (MediaStruct));
                 CHECK_MALLOCED(doc->media);
@@ -860,9 +853,9 @@ scan_ok:
 		     */
 		    if (strcasecmp(doc->media[doc->nummedia].name,
 			       dmp->name) == 0) {
-			PS_free(doc->media[doc->nummedia].name);
+			free(doc->media[doc->nummedia].name);
 			doc->media[doc->nummedia].name =
-				(char *)PS_malloc(strlen(dmp->name)+1);
+				(char *)malloc(strlen(dmp->name)+1);
                         CHECK_MALLOCED(doc->media[doc->nummedia].name);
 			strcpy(doc->media[doc->nummedia].name, dmp->name);
 			doc->media[doc->nummedia].width = dmp->width;
@@ -873,7 +866,7 @@ scan_ok:
 		if (doc->media[doc->nummedia].width != 0 &&
 		    doc->media[doc->nummedia].height != 0) doc->nummedia++;
 		else
-		    PS_free(doc->media[doc->nummedia].name);
+		    free(doc->media[doc->nummedia].name);
 	    }
 	    preread=1;
 	    while (readline(fd, &line, &position, &line_len) &&
@@ -882,7 +875,7 @@ scan_ok:
 		next_char = line + length("%%+");
 		while ((cp = ps_gettext(next_char, &next_char))) {
 		    doc->media = (Media)
-				 PS_realloc(doc->media,
+				 realloc(doc->media,
 					 (doc->nummedia+1)*
 					 sizeof (MediaStruct));
                     CHECK_MALLOCED(doc->media);
@@ -905,7 +898,7 @@ scan_ok:
 		    if (doc->media[doc->nummedia].width != 0 &&
 			doc->media[doc->nummedia].height != 0) doc->nummedia++;
 		    else
-			PS_free(doc->media[doc->nummedia].name);
+			free(doc->media[doc->nummedia].name);
 		}
 	    }
 	    section_len += line_len;
@@ -978,7 +971,7 @@ scan_ok:
 			break;
 		    }
 		}
-		PS_free(cp);
+		free(cp);
 	    } else if (page_bb_set == NONE &&
 		       iscomment(line+2, "PageBoundingBox:")) {
 		if (sec_sscanf(line+length("%%PageBoundingBox:"), "%d %d %d %d",
@@ -1104,7 +1097,7 @@ scan_ok:
 			break;
 		    }
 		}
-		PS_free(cp);
+		free(cp);
 	    } else if (page_bb_set == NONE &&
 		       iscomment(line+2, "PageBoundingBox:")) {
 		if (sec_sscanf(line+length("%%PageBoundingBox:"), "%d %d %d %d",
@@ -1179,7 +1172,7 @@ newpage:
     while (DSCcomment(line) && iscomment(line+2, "Page:")) {
 	if (maxpages == 0) {
 	    maxpages = 1;
-	    doc->pages = (struct page *) PS_calloc(maxpages, sizeof(struct page));
+	    doc->pages = (struct page *) calloc(maxpages, sizeof(struct page));
             CHECK_MALLOCED(doc->pages);
 	}
 	label = ps_gettext(line+length("%%Page:"), &next_char);
@@ -1188,7 +1181,7 @@ newpage:
 	    ignore = thispage != 1;
 	}
 	if (!ignore && thispage != nextpage) {
-	    PS_free(label);
+	    free(label);
 	    doc->numpages--;
 	    goto continuepage;
 	}
@@ -1196,7 +1189,7 @@ newpage:
 	if (doc->numpages == maxpages) {
 	    maxpages++;
 	    doc->pages = (struct page *)
-			 PS_realloc(doc->pages, maxpages*sizeof (struct page));
+			 realloc(doc->pages, maxpages*sizeof (struct page));
             CHECK_MALLOCED(doc->pages);
 
 	}
@@ -1236,7 +1229,7 @@ continuepage:
 			break;
 		    }
 		}
-		PS_free(cp);
+		free(cp);
 	    } else if (doc->pages[doc->numpages].media == NULL &&
 		       iscomment(line+2, "PaperSize:")) {
 		cp = ps_gettext(line+length("%%PaperSize:"), NULL);
@@ -1250,7 +1243,7 @@ continuepage:
 			break;
 		    }
 		}
-		PS_free(cp);
+		free(cp);
 	    } else if ((page_bb_set == NONE || page_bb_set == ATEND) &&
 		       iscomment(line+2, "PageBoundingBox:")) {
 		sec_sscanf(line+length("%%PageBoundingBox:"), "%256s", text);
@@ -1317,7 +1310,7 @@ continuepage:
 	if (!DSCcomment(line)) {
 	    /* Do nothing */
 	} else if (iscomment(line+2, "Page:")) {
-	    PS_free(ps_gettext(line+length("%%Page:"), &next_char));
+	    free(ps_gettext(line+length("%%Page:"), &next_char));
 	    if (sec_sscanf(next_char, "%d", &thispage) != 1) thispage = 0;
 	    if (!ignore && thispage == nextpage) {
 		if (doc->numpages > 0) {
@@ -1410,7 +1403,7 @@ continuepage:
 	if (!preread) section_len += line_len;
 	preread = 0;
 	if (DSCcomment(line) && iscomment(line+2, "Page:")) {
-	    PS_free(ps_gettext(line+length("%%Page:"), &next_char));
+	    free(ps_gettext(line+length("%%Page:"), &next_char));
 	    if (sec_sscanf(next_char, "%d", &thispage) != 1) thispage = 0;
 	    if (!ignore && thispage == nextpage) {
 		if (doc->numpages > 0) {
@@ -1453,16 +1446,16 @@ psfree(doc)
     BEGINMESSAGE(psfree)
     if (doc) {
 	for (i=0; i<doc->numpages; i++) {
-	    if (doc->pages[i].label) PS_free(doc->pages[i].label);
+	    if (doc->pages[i].label) free(doc->pages[i].label);
 	}
 	for (i=0; i<doc->nummedia; i++) {
-	    if (doc->media[i].name) PS_free(doc->media[i].name);
+	    if (doc->media[i].name) free(doc->media[i].name);
 	}
-	if (doc->title) PS_free(doc->title);
-	if (doc->date) PS_free(doc->date);
-	if (doc->pages) PS_free(doc->pages);
-	if (doc->media) PS_free(doc->media);
-	PS_free(doc);
+	if (doc->title) free(doc->title);
+	if (doc->date) free(doc->date);
+	if (doc->pages) free(doc->pages);
+	if (doc->media) free(doc->media);
+	free(doc);
     }
     ENDMESSAGE(psfree)
 }
@@ -1488,7 +1481,7 @@ gettextline(line)
 	return ps_gettext(line, NULL);
     } else {
 	if (strlen(line) == 0) {ENDMESSAGE(gettextline) return NULL;}
-	cp = (char *) PS_malloc(strlen(line));
+	cp = (char *) malloc(strlen(line));
 	CHECK_MALLOCED(cp);
 	strncpy(cp, line, strlen(line)-1);
 	cp[strlen(line)-1] = '\0';
@@ -1591,7 +1584,7 @@ ps_gettext(line, next_char)
     *cp = '\0';
     if (next_char) *next_char = line;
     if (!quoted && strlen(text) == 0) {ENDMESSAGE(ps_gettext) return NULL;}
-    cp = (char *) PS_malloc(strlen(text)+1);
+    cp = (char *) malloc(strlen(text)+1);
     CHECK_MALLOCED(cp);
     strcpy(cp, text);
     ENDMESSAGE(ps_gettext)
@@ -1630,7 +1623,7 @@ static FileData ps_io_init(file)
 
    BEGINMESSAGE(ps_io_init)
 
-   fd = (FileData) PS_XtMalloc(size);
+   fd = (FileData) XtMalloc(size);
    memset((void*) fd ,0,(size_t)size);
 
    rewind(file);
@@ -1638,7 +1631,7 @@ static FileData ps_io_init(file)
    FD_FILE_DESC = fileno(file);
    FD_FILEPOS   = GV_FTELL(file);
    FD_BUF_SIZE  = (2*LINE_CHUNK_SIZE)+1;
-   FD_BUF       = PS_XtMalloc(FD_BUF_SIZE);
+   FD_BUF       = XtMalloc(FD_BUF_SIZE);
    FD_BUF[0]    = '\0';
    ENDMESSAGE(ps_io_init)
    return(fd);
@@ -1653,8 +1646,8 @@ ps_io_exit(fd)
    FileData fd;
 {
    BEGINMESSAGE(ps_io_exit)
-   PS_XtFree(FD_BUF);
-   PS_XtFree(fd);
+   XtFree(FD_BUF);
+   XtFree((XtPointer)fd);
    ENDMESSAGE(ps_io_exit)
 }
 
@@ -1780,7 +1773,7 @@ static char * ps_io_fgetchars(fd,num)
 	    */
             FD_BUF_SIZE    = FD_BUF_SIZE+LINE_CHUNK_SIZE+1;
             IMESSAGE(FD_BUF_SIZE)
-            FD_BUF         = PS_XtRealloc(FD_BUF,FD_BUF_SIZE);
+            FD_BUF         = XtRealloc(FD_BUF,FD_BUF_SIZE);
          }
       }
 
@@ -2016,7 +2009,7 @@ pscopyuntil(fd, to, begin, end, comment)
       line = ps_io_fgetchars(fd,-1);
       if (!line) break;
       if (comment && strncmp(line, comment, comment_length) == 0) {
-         char *cp = (char *) PS_malloc(strlen(line)+1);
+         char *cp = (char *) malloc(strlen(line)+1);
          INFSMESSAGE(encountered specified,comment)
          CHECK_MALLOCED(cp);
          strcpy(cp, line);
@@ -2125,7 +2118,7 @@ pscopydoc(dest_file,src_filename,d,pagelist)
        SMESSAGE(comment)
        here = ps_io_ftell(fd);
        if (pages_written || pages_atend) {
-          PS_free(comment);
+          free(comment);
           continue;
        }
        sec_sscanf(comment+length("%%Pages:"), "%256s", text);
@@ -2143,7 +2136,7 @@ pscopydoc(dest_file,src_filename,d,pagelist)
           }
           pages_written = True;
        }
-       PS_free(comment);
+       free(comment);
    }
    pscopyuntil(fd, dest_file, d->beginpreview, d->endpreview,NULL);
    pscopyuntil(fd, dest_file, d->begindefaults, d->enddefaults,NULL);
@@ -2156,7 +2149,7 @@ pscopydoc(dest_file,src_filename,d,pagelist)
       if (pagelist[j]=='*') {
           comment = pscopyuntil(fd,dest_file,d->pages[i].begin,d->pages[i].end, "%%Page:");
           fprintf(dest_file, "%%%%Page: %s %d\n",d->pages[i].label, page++);
-          PS_free(comment);
+          free(comment);
           pscopyuntil(fd, dest_file, -1, d->pages[i].end,NULL);
       }
    }
@@ -2165,7 +2158,7 @@ pscopydoc(dest_file,src_filename,d,pagelist)
    while ((comment = pscopyuntil(fd, dest_file, here, d->endtrailer, "%%Pages:"))) {
       here = ps_io_ftell(fd);
       if (pages_written) {
-         PS_free(comment);
+         free(comment);
          continue;
       }
       switch (sec_sscanf(comment+length("%%Pages:"), "%*d %d", &i)) {
@@ -2177,7 +2170,7 @@ pscopydoc(dest_file,src_filename,d,pagelist)
             break;
       }
       pages_written = True;
-      PS_free(comment);
+      free(comment);
    }
    fclose(src_file);
    ps_io_exit(fd);
